# eric7.Plugins.VcsPlugins.vcsMercurial.HgRevisionsSelectionDialog

Module implementing a dialog to enter the revisions for the hg diff command.

### Global Attributes

None

### Classes

HgRevisionsSelectionDialog | Class implementing a dialog to enter the revisions for the hg diff command.

### Functions

None

## HgRevisionsSelectionDialog

Class implementing a dialog to enter the revisions for the hg diff command.

### Derived from

QDialog, Ui_HgRevisionsSelectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgRevisionsSelectionDialog | Constructor
__getRevision | Private method to generate the revision.
__updateOK | Private slot to update the OK button.
getRevisions | Public method to get the revisions.

### Static Methods

None

#### HgRevisionsSelectionDialog (Constructor)

HgRevisionsSelectionDialog(tagsList, branchesList, bookmarksList=None, parent=None)

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
parent (QWidget)
  parent widget of the dialog

#### HgRevisionsSelectionDialog.__getRevision

__getRevision(no)

Private method to generate the revision.

no (int)
  revision number to generate (1 or 2)

Return:
  revision

Return Type:
  str

#### HgRevisionsSelectionDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgRevisionsSelectionDialog.getRevisions

getRevisions()

Public method to get the revisions.

Return:
  list of two revisions

Return Type:
  list of [str, str]

Up